==> savane-1.0.5a.tar.gz: savane/frontend/php/register/requirements.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: requirements.php,v 1.18 2004/03/13 18:22:06 yeupou Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#                           Mathieu Roy <yeupou--at--gnu.org>
#
#  Copyright 2004      (c) ...
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../include/pre.php";  # Initial db and session library, opens session
session_require(array(isloggedin=>1));
$HTML->header(array(title=>_("Services and Requirements")));

print '<h2>'._("Step").' 1: '._("Services and Requirements").'</h2>';

# get site-specific content
utils_get_content("register/requirements");

print '<form action="basicinfo.php" method="post">';
print '<div align="center">';
print '<h3>'._("Proceed to Next Step").' :</h3>';
print '<input type=submit name="Submit" value="'._("Step").' 2: '._("Project Description and Dependencies").'">';
print '</div>';
print '</form>';

$HTML->footer(array());
?>

==> savane-1.0.6.tar.gz: savane/frontend/php/register/requirements.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: requirements.php,v 1.19 2005/01/13 09:20:42 yeupou Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#                          Mathieu Roy <yeupou--at--gnu.org>
#
#  Copyright 2005      (c) Sylvain Beucler <beuc--beuc.net>
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../include/pre.php";  # Initial db and session library, opens session
#session_require(array(isloggedin=>1));
$HTML->header(array(title=>_("Services and Requirements")));

print '<h2>'._("Step").' 1: '._("Services and Requirements").'</h2>';

# get site-specific content
utils_get_content("register/requirements");

print '<form action="basicinfo.php" method="post">';
print '<div align="center">';
print '<h3>'._("Proceed to Next Step (Requires Login)").' :</h3>';
print '<input type=submit name="Submit" value="'._("Step").' 2: '._("Project Description and Dependencies").'">';
print '</div>';
print '</form>';

$HTML->footer(array());
?>
